@@ -44,6 +44,7 @@ struct TerminalGraphicsPlacement_t {
     int z, X, Y, col, row, cols, rows;
     qreal opacity;
     bool scrolling;
+    enum source { Sixel, iTerm, Kitty } source;
 };
 
 namespace Konsole
@@ -634,6 +635,8 @@ public:
      */
     int droppedLines() const;
 
+    int fastDroppedLines() const;
+
     /**
      * Resets the count of the number of lines dropped from
      * the history.
@@ -673,6 +676,7 @@ public:
     void setEnableUrlExtractor(const bool enable);
 
     static const Character DefaultChar;
+    static const Character VisibleChar;
 
     // Return the total number of lines before resize (fix scroll glitch)
     int getOldTotalLines();
@@ -687,6 +691,7 @@ public:
                       int &cols,
                       int row = -1,
                       int col = -1,
+                      enum TerminalGraphicsPlacement_t::source source = TerminalGraphicsPlacement_t::Sixel,
                       bool scrolling = true,
                       int moveCursor = 1,
                       bool leaveText = false,
@@ -705,6 +710,8 @@ public:
     }
     void setIgnoreWcWidth(bool ignore);
 
+    QList<int> getCharacterCounts() const;
+
 private:
     // copies a line of text from the screen or history into a stream using a
     // specified character decoder.  Returns the number of lines actually copied,
@@ -804,6 +811,7 @@ private:
     QRect _lastScrolledRegion;
 
     int _droppedLines;
+    int _fastDroppedLines;
 
     int _oldTotalLines;
     bool _isResize;
@@ -820,8 +828,8 @@ private:
     int _cuY;
 
     // select mode cursor location
-    int _selCuX;
-    int _selCuY;
+    int _selCuX{};
+    int _selCuY{};
 
     // cursor color and rendition info
     CharacterColor _currentForeground;
