@@ -16,7 +16,6 @@
 
 // KDE
 #include <KPluginFactory>
-#include <kcoreaddons_version.h>
 
 // Others
 #if defined(Q_OS_LINUX)
@@ -94,10 +93,6 @@ void TerminalInterfaceTest::testTerminalInterfaceNoShell()
 // Test with default shell running
 void TerminalInterfaceTest::testTerminalInterface()
 {
-    // Maybe https://bugreports.qt.io/browse/QTBUG-82351 ???
-    QSKIP("Skipping on CI suse_tumbelweed_qt64", SkipSingle);
-    return;
-
     QString currentDirectory;
 
     // create a Konsole part and attempt to connect to it
@@ -112,14 +107,6 @@ void TerminalInterfaceTest::testTerminalInterface()
     // Start a shell in given directory
     terminal->showShellInDir(QDir::home().path());
 
-// After fa398f56, the CI test failed; also the KF was updated on that build.
-// TODO: research this more
-#if defined(Q_OS_FREEBSD)
-    return;
-#endif
-    // Skip this for now on FreeBSD
-    // -1 is current foreground process and name for process 0 is "kernel"
-
     int foregroundProcessId = terminal->foregroundProcessId();
     QCOMPARE(foregroundProcessId, -1);
     QString foregroundProcessName = terminal->foregroundProcessName();
@@ -127,8 +114,8 @@ void TerminalInterfaceTest::testTerminalInterface()
 
     // terminalProcessId() is the user's default shell
     // FIXME: find a way to verify this
-    int terminalProcessId = terminal->terminalProcessId();
 #if defined(Q_OS_LINUX)
+    int terminalProcessId = terminal->terminalProcessId();
     const int uid = getuid();
     QFile passwdFile(QStringLiteral("/etc/passwd"));
     QString defaultExePath;
@@ -151,6 +138,40 @@ void TerminalInterfaceTest::testTerminalInterface()
     }
 #endif
 
+    // Nothing running in foreground
+    foregroundProcessId = terminal->foregroundProcessId();
+    QCOMPARE(foregroundProcessId, -1);
+    foregroundProcessName = terminal->foregroundProcessName();
+    QCOMPARE(foregroundProcessName, QString());
+
+    delete _terminalPart;
+}
+
+// Test with default shell running using QSignalSpy
+void TerminalInterfaceTest::testTerminalInterfaceUsingSpy()
+{
+#if defined(Q_OS_WIN)
+    return;
+#endif
+    QString currentDirectory;
+
+    // create a Konsole part and attempt to connect to it
+    _terminalPart = createPart();
+    if (_terminalPart == nullptr) {
+        QFAIL("konsolepart not found.");
+    }
+
+    TerminalInterface *terminal = qobject_cast<TerminalInterface *>(_terminalPart);
+    QVERIFY(terminal);
+
+    // Start a shell in given directory
+    terminal->showShellInDir(QDir::home().path());
+
+    int foregroundProcessId = terminal->foregroundProcessId();
+    QCOMPARE(foregroundProcessId, -1);
+    QString foregroundProcessName = terminal->foregroundProcessName();
+    QCOMPARE(foregroundProcessName, QString());
+
     // Let's try using QSignalSpy
     // https://community.kde.org/Guidelines_and_HOWTOs/UnitTests
     // QSignalSpy is really a QList of QLists, so we take the first
@@ -246,6 +267,7 @@ void TerminalInterfaceTest::testTerminalInterface()
     QCOMPARE(destroyedSpy.count(), 1);
 }
 
+// Oct 2023: KParts merge TerminalInterfaceV2 into TerminalInterface
 void TerminalInterfaceTest::testTerminalInterfaceV2()
 {
     // Use the built-in profile for testing
