@@ -652,6 +652,15 @@ void Session::setSessionAttribute(int what, const QString &caption)
         }
     }
 
+    if (what == SessionColor) {
+        QString colorString = caption.section(QLatin1Char(';'), 0, 0);
+        QColor color = QColor(colorString);
+        if (color.isValid()) {
+            setColor(color);
+            tabColorSetByUser(true);
+        }
+    }
+
     if (what == CurrentDirectory) {
         _reportedWorkingUrl = QUrl::fromUserInput(caption);
         Q_EMIT currentDirectoryChanged(currentWorkingDirectory());
@@ -2131,6 +2140,10 @@ void Session::setSelectMode(bool mode)
 
 void Session::setColor(const QColor &color)
 {
+    if (_tabColor == color) {
+        return;
+    }
+
     _tabColor = color;
     Q_EMIT sessionAttributeChanged();
 }
