@@ -12,11 +12,12 @@
 #include <QAccessibleTextInterface>
 #include <QAccessibleWidget>
 
-#include "terminalDisplay/TerminalDisplay.h"
-#include "ScreenWindow.h"
 #include "Screen.h"
+#include "ScreenWindow.h"
+#include "terminalDisplay/TerminalDisplay.h"
 
-namespace Konsole {
+namespace Konsole
+{
 /**
  * Class implementing the QAccessibleInterface for the terminal display.
  * This exposes information about the display to assistive technology using the QAccessible framework.
